"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expirationDateDefaultValue = expirationDateDefaultValue;
exports.useByDateDefaultValue = useByDateDefaultValue;
const typesLib = require("@sage/xtrem-decimal");
const xtrem_date_time_1 = require("@sage/xtrem-date-time");
/**
 * Return the default value corresponding to the product rule for the expiry date
 * @param product
 * @param effectiveDate
 * @return
 */
function expirationDateDefaultValue(productExpirationManagementMode, productExpirationLeadTime, productExpirationLeadTimeUnit, effectiveDate) {
    let expiryDate;
    expiryDate = effectiveDate ? xtrem_date_time_1.date.parse(effectiveDate) : null;
    if (typesLib.strictEq(expiryDate, null))
        return null;
    if (typesLib.strictNe(productExpirationManagementMode, null)) {
        // Check if the product is not managed in expiration mode
        if (typesLib.strictEq(productExpirationManagementMode, 'notManaged') || typesLib.strictEq(productExpirationManagementMode, 'manualEntry')) {
            return null;
        }
        else {
            if (typesLib.strictEq(productExpirationLeadTimeUnit, 'calendarDays')) {
                // the expiry date is effectiveDate + expirationLeadTime duration value in days
                expiryDate = expiryDate.addDays(productExpirationLeadTime);
            }
            // Check if expiration time unit is months
            if (typesLib.strictEq(productExpirationLeadTimeUnit, 'month')) {
                // the expiry date is effectiveDate + expirationLeadTime in months
                expiryDate = expiryDate.addMonths(productExpirationLeadTime);
            }
            if (typesLib.strictEq(productExpirationManagementMode, 'roundingMonthEnd') || typesLib.strictEq(productExpirationManagementMode, 'roundingBeginningMonth1')) {
                // Check if the product expiration mode indicate a rounding rule
                if (typesLib.strictEq(productExpirationManagementMode, 'roundingMonthEnd')) {
                    // if the rounding rule is month end
                    expiryDate = expiryDate.endOfMonth();
                }
                else if (typesLib.strictEq(productExpirationManagementMode, 'roundingBeginningMonth1')) {
                    // if the rounding rule is next month begin
                    expiryDate = expiryDate.begOfMonth().addMonths(1);
                }
            }
        }
    }
    else {
        return null;
    }
    // if none of the above conditions are met:
    return expiryDate ? expiryDate.format('YYYY-MM-DD') : null;
}
function useByDateDefaultValue(expirationDate, referenceDate, productExpirationManagement, useByDateCoefficient) {
    let _tmpExpirationDate = expirationDate ? xtrem_date_time_1.date.parse(expirationDate) : null;
    let _tmpReferenceDate = referenceDate ? xtrem_date_time_1.date.parse(referenceDate) : null;
    let useByDate;
    if (typesLib.strictEq(_tmpExpirationDate, null) && typesLib.strictEq(_tmpReferenceDate, null))
        return null;
    if (typesLib.strictNe(productExpirationManagement, null)) {
        // Check if the product is not managed in expiration mode
        if (typesLib.strictEq(productExpirationManagement, 'notManaged') || typesLib.strictEq(productExpirationManagement, 'manualEntry')) {
            return null;
        }
        if (typesLib.gt(useByDateCoefficient, 1) || typesLib.strictEq(useByDateCoefficient, 0) || typesLib.lt(useByDateCoefficient, 0)) {
            useByDateCoefficient = 1;
        }
        if (_tmpExpirationDate) {
            if (_tmpReferenceDate && typesLib.gt(_tmpExpirationDate, _tmpReferenceDate)) {
                const delay = typesLib.round(typesLib.mul(useByDateCoefficient, _tmpExpirationDate.daysDiff(_tmpReferenceDate)));
                useByDate = _tmpReferenceDate.addDays(delay);
            }
            else {
                useByDate = _tmpExpirationDate;
            }
        }
        else {
            return null;
        }
    }
    else {
        return null;
    }
    return useByDate ? useByDate.format('YYYY-MM-DD') : null;
}
//# sourceMappingURL=defaultValue.js.map