"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clean = void 0;
const xtrem_cli_lib_1 = require("@sage/xtrem-cli-lib");
const fs = require("fs");
const path = require("path");
function safeRm(fileOrDir, options) {
    try {
        fs.rmSync(fileOrDir, options);
    }
    catch (e) {
        if (e.code !== 'ENOENT') {
            throw e;
        }
    }
}
const clean = (executionMode, dir, options) => {
    (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Cleaning working directory...');
    const buildDir = path.resolve(dir, 'build');
    safeRm(buildDir, { recursive: true });
    if (options?.force) {
        const apiDir = path.resolve(dir, 'api');
        const apiPackage = path.resolve(apiDir, 'package.json');
        safeRm(apiPackage);
        const apiDeclaration = path.resolve(apiDir, 'api.d.ts');
        safeRm(apiDeclaration);
    }
    const coverageDir = path.resolve(dir, 'coverage');
    safeRm(coverageDir, { recursive: true });
    const routingPath = path.join(dir, 'routing.json');
    safeRm(routingPath, { force: true });
    (0, xtrem_cli_lib_1.printSuccess)(executionMode, 'Working directory is clear.');
};
exports.clean = clean;
//# sourceMappingURL=clean.js.map