"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compileServer = void 0;
const xtrem_cli_lib_1 = require("@sage/xtrem-cli-lib");
const xtrem_cli_transformers_1 = require("@sage/xtrem-cli-transformers");
const ts = require("typescript");
const utils_1 = require("./utils");
const compileServer = (executionMode, dir, options) => {
    (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Compiling server side artifacts...');
    if (options?.isUsingReferences) {
        (0, xtrem_cli_lib_1.printInfo)(executionMode, "Project references won't be built since this feature is yet to be implemented :/");
    }
    try {
        const program = (0, utils_1.getTsProgram)(dir);
        const emitResult = program.emit(undefined, undefined, undefined, undefined, {
            before: [
                ...(options?.doNotGenerateRoutingFile ? [] : [xtrem_cli_transformers_1.notificationListenerTransformer]),
                xtrem_cli_transformers_1.decimalTransformer,
                xtrem_cli_transformers_1.messageTransformer,
                xtrem_cli_transformers_1.nodePropertyNameExtractor,
                xtrem_cli_transformers_1.serviceOptionNameExtractor,
                xtrem_cli_transformers_1.activityNameExtractor,
                xtrem_cli_transformers_1.enumTransformer,
                xtrem_cli_transformers_1.menuItemTransformer,
                xtrem_cli_transformers_1.dataTypesNameExtractor,
            ],
        });
        const allDiagnostics = ts.getPreEmitDiagnostics(program).concat(emitResult.diagnostics);
        allDiagnostics.forEach((0, utils_1.printCompilerError)(executionMode));
        if (allDiagnostics.length === 0) {
            (0, xtrem_cli_lib_1.printSuccess)(executionMode, 'All server side artifacts compiled.');
        }
        else {
            (0, xtrem_cli_lib_1.quitWithError)(executionMode, 'Failed to compile server side artifacts.');
        }
    }
    catch (e) {
        (0, xtrem_cli_lib_1.printError)(executionMode, e.message);
        (0, xtrem_cli_lib_1.quitWithError)(executionMode, 'Failed to compile server side artifacts.');
    }
};
exports.compileServer = compileServer;
//# sourceMappingURL=compile-server.js.map