"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateSingleDefinition = void 0;
const xtrem_cli_lib_1 = require("@sage/xtrem-cli-lib");
const xtrem_dts_bundle_1 = require("@sage/xtrem-dts-bundle");
const fs = require("fs");
const glob_1 = require("glob");
const path = require("path");
// dts-generator generates an invalid definition file if directory contains an empty file.
function checkNoEmptySourceFile(executionMode, dir) {
    const emptyPath = glob_1.glob.sync('./**/*.ts', { cwd: dir, absolute: true, realpath: true }).find(
    // test stat size first to only read small files
    p => fs.statSync(p).size < 10 && fs.readFileSync(p, 'utf8').trim().length === 0);
    if (emptyPath) {
        // BL: Temporary change to prevent breaking builds
        (0, xtrem_cli_lib_1.printWarning)(executionMode, `${emptyPath}: empty file`);
    }
}
const generateSingleDefinition = (executionMode, dir) => {
    (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Creating single definition file...');
    const packageFile = path.resolve(dir, 'package.json');
    checkNoEmptySourceFile(executionMode, dir);
    (0, xtrem_dts_bundle_1.dtsBundleApi)(packageFile, path.resolve(dir, 'build', 'package-definition.d.ts'));
    (0, xtrem_cli_lib_1.printSuccess)(executionMode, 'Single definition file created.');
};
exports.generateSingleDefinition = generateSingleDefinition;
//# sourceMappingURL=dts-generator.js.map