import { Handle, Position } from 'reactflow';
import * as React from 'react';
import { useSelector } from 'react-redux';
import { getTextForLocale } from '@sage/xtrem-shared';
import Icon from 'carbon-react/esm/components/icon';
import IconButton from 'carbon-react/esm/components/icon-button';
import { openPageDialog } from '../../../service/dialog-service';
import { removeTransientNodeDataProperties, useSubsequentWorkflowNodes, useWorkflowNodeVariables, } from './workflow-component-utils';
import { resolveDetailedIcon } from '../../../utils/detailed-icons-utils';
import { WorkflowContext } from './workflow-context-provider';
import Button from 'carbon-react/esm/components/button';
import SplitButton from 'carbon-react/esm/components/split-button';
import { localize } from '../../../service/i18n-service';
import { getStore } from '../../../redux';
import { ConditionNodeLabel } from './condition-node-label';
export function CustomNode({ data, isConnectable, id }) {
    const context = React.useContext(WorkflowContext);
    const subsequentNodes = useSubsequentWorkflowNodes(id, context?.screenId, context?.elementId);
    const locale = getStore().getState().applicationContext?.locale || 'base';
    const { inputVariables, oldRootPaths } = useWorkflowNodeVariables(id, context?.screenId, context?.elementId);
    const workflowNodeType = useSelector(s => s.workflowNodes?.find(n => n.key === data.type) || null);
    const headerLabel = React.useMemo(() => {
        if (workflowNodeType?.type === 'condition') {
            return localize('@sage/xtrem-ui/workflow-component-header-label-condition', 'Condition');
        }
        if (workflowNodeType?.type === 'event') {
            return localize('@sage/xtrem-ui/workflow-component-header-label-start', 'Starts when');
        }
        return localize('@sage/xtrem-ui/workflow-component-header-label-action', 'Do');
    }, [workflowNodeType?.type]);
    const onConfigurationOpen = React.useCallback(async () => {
        if (!workflowNodeType?.configurationPage || !context?.onNodeDataChange) {
            return;
        }
        try {
            const result = await openPageDialog(workflowNodeType.configurationPage, { inputVariables: inputVariables, oldRootPaths: oldRootPaths }, { values: removeTransientNodeDataProperties(data), rightAligned: true, size: 'extra-large' });
            context.onNodeDataChange(id, { ...result, type: data.type });
        }
        catch (e) {
            // intentionally left empty
        }
    }, [workflowNodeType?.configurationPage, inputVariables, oldRootPaths, data, context, id]);
    const onInsertBelowButtonClick = React.useCallback(() => {
        context?.onNodeBelowNode(id);
    }, [context, id]);
    const onInsertBelowConditionButtonClick = React.useCallback(() => {
        context?.onNodeBelowNode(id, 'condition');
    }, [context, id]);
    const onInsertBelowActionsButtonClick = React.useCallback(() => {
        context?.onNodeBelowNode(id, 'action');
    }, [context, id]);
    if (!workflowNodeType) {
        return null;
    }
    return (React.createElement("div", { className: "e-workflow-node-wrapper" },
        React.createElement(Handle, { type: "target", position: Position.Top, id: "in", isConnectable: isConnectable },
            React.createElement("div", { className: "e-workflow-node-header" },
                React.createElement("div", { className: "e-workflow-node-header-content", style: {
                        backgroundColor: 'var(--colorsSemanticNeutral500)',
                        color: 'var(--colorsYang100)',
                    } }, headerLabel))),
        React.createElement("div", { className: `e-workflow-node e-workflow-node-${workflowNodeType.type} e-workflow-node-${workflowNodeType.key}`, "data-testid": `e-workflow-node e-workflow-node-${workflowNodeType.type} e-workflow-node-${workflowNodeType.key}`, "data-nodeid": id },
            workflowNodeType.type !== 'condition' && (React.createElement("div", { className: "e-workflow-node-icon-wrapper", style: { backgroundColor: workflowNodeType.color } },
                React.createElement("div", { className: "e-workflow-node-icon", style: {
                        mask: `url(${resolveDetailedIcon(workflowNodeType.icon)}) no-repeat left center`,
                        maskSize: '24px 24px',
                        backgroundColor: 'var(--colorsUtilityYang100)',
                    } }))),
            React.createElement("div", { className: `e-workflow-node-body e-workflow-node-${workflowNodeType.type}-body` },
                React.createElement("div", { className: "e-workflow-node-title" },
                    React.createElement("div", { className: "e-workflow-node-title-label" }, getTextForLocale(data.localizedTitle, locale) || data.title || workflowNodeType.title),
                    workflowNodeType.configurationPage && !context?.isReadOnly && (React.createElement(IconButton, { onClick: onConfigurationOpen },
                        React.createElement(Icon, { ml: workflowNodeType.type !== 'condition' ? '8px' : undefined, type: "edit", color: "--colorsUtilityYin090" })))),
                data.subtitle && React.createElement("div", { className: "e-workflow-node-subtitle" }, data.subtitle),
                data.details && React.createElement("div", { className: "e-workflow-node-details" }, data.details)),
            workflowNodeType.type === 'condition' && (React.createElement(React.Fragment, null,
                React.createElement(ConditionNodeLabel, { sourceHandleId: "out-true", sourceX: -64, sourceY: 27 }),
                React.createElement(ConditionNodeLabel, { sourceHandleId: "out-false", sourceX: 257, sourceY: 27 }),
                React.createElement(Handle, { type: "source", position: Position.Right, id: "out-false", isConnectable: isConnectable }))),
            React.createElement(Handle, { type: "source", position: workflowNodeType.type === 'condition' ? Position.Left : Position.Bottom, id: workflowNodeType.type === 'condition' ? 'out-true' : 'out', isConnectable: isConnectable })),
        subsequentNodes.length === 0 && workflowNodeType?.type !== 'condition' && (React.createElement("div", { className: "e-workflow-node-add-button" },
            React.createElement(SplitButton, { text: localize('@sage/xtrem-ui/workflow-component-add-step', 'Add step'), size: "small", iconType: "plus", onClick: onInsertBelowButtonClick },
                React.createElement(Button, { iconType: "tick", onClick: onInsertBelowActionsButtonClick }, localize('@sage/xtrem-ui/workflow-component-add-action', 'Add action')),
                React.createElement(Button, { iconType: "split", onClick: onInsertBelowConditionButtonClick }, localize('@sage/xtrem-ui/workflow-component-add-condition', 'Add condition')))))));
}
//# sourceMappingURL=custom-node.js.map