import { connect } from 'react-redux';
import * as xtremRedux from '../../redux';
import { XtremTabs } from '../ui/tabs/xtrem-tabs';
import React from 'react';
import { ConnectedTableSidebarSection } from './table-sidebar-section';
import { TableSidebarCard } from './table-sidebar-card';
import { resolveByValue } from '../../utils/resolve-value-utils';
import { withCollectionValueItemSubscription } from '../connected-collection';
import { objectKeys } from '@sage/xtrem-shared';
import Form from 'carbon-react/esm/components/form';
import Button from 'carbon-react/esm/components/button';
import { localize } from '../../service/i18n-service';
import { getResolvedSidebarLayout, getSidebarNormalFields } from '../../utils/state-utils';
import Loader from 'carbon-react/esm/components/loader';
export function TableSidebarBody({ cardDefinition, columns, elementId, hasExternalErrors, isNewRecord, isScreenLessThanM, level, recordId, recordValue, screenId, sidebarLayoutDefinition, validationErrors, value, onConfirm, onCancel, }) {
    const sections = React.useMemo(() => objectKeys(sidebarLayoutDefinition).reduce((acc, currentKey) => {
        const sectionDefinition = sidebarLayoutDefinition[currentKey];
        const isHidden = (!!screenId &&
            resolveByValue({
                propertyValue: sectionDefinition.isHidden,
                rowValue: recordValue,
                fieldValue: recordId,
                screenId,
                skipHexFormat: true,
            })) ||
            false;
        if (isHidden) {
            return acc;
        }
        let errorMessage;
        objectKeys(sectionDefinition.blocks).some(blockKey => {
            const fields = sectionDefinition.blocks[blockKey].fields;
            // Find if inside validation errors columnId match with some of the fields array and return that validationError
            const validationError = validationErrors.find(error => fields && fields.includes(error.columnId));
            if (validationError?.message) {
                errorMessage = validationError?.message;
                return true;
            }
            return false;
        });
        acc.push({ id: currentKey, title: sectionDefinition.title, validationMessage: errorMessage });
        return acc;
    }, []), [recordId, recordValue, screenId, sidebarLayoutDefinition, validationErrors]);
    const [currentTab, setCurrentTab] = React.useState(sections[0]?.id || '');
    const applyAndAddNew = isScreenLessThanM
        ? localize('@sage/xtrem-ui/sidebar-mobile-apply-changes-and-create-new', 'Apply & new')
        : localize('@sage/xtrem-ui/sidebar-apply-changes-and-create-new', 'Apply and add new');
    if (!recordId) {
        return React.createElement(Loader, null);
    }
    return (React.createElement(Form, { onSubmit: (ev) => {
            ev.preventDefault();
        }, rightSideButtons: React.createElement(React.Fragment, null,
            isNewRecord && (React.createElement(Button, { "data-testid": "e-table-sidebar-confirm-and-add-new-button", buttonType: "secondary", onClick: () => onConfirm(true), ml: "24px", disabled: validationErrors.length > 0 || hasExternalErrors }, applyAndAddNew)),
            React.createElement(Button, { "data-testid": "e-table-sidebar-confirm-button", buttonType: "primary", onClick: () => onConfirm(false), ml: "24px", disabled: validationErrors.length > 0 || hasExternalErrors }, localize('@sage/xtrem-ui/sidebar-apply-changes', 'Apply'))), leftSideButtons: React.createElement(Button, { "data-testid": "e-table-sidebar-cancel-button", buttonType: "tertiary", onClick: onCancel, ml: "24px" }, localize('@sage/xtrem-ui/cancel', 'Cancel')) },
        React.createElement("div", { "data-testid": "e-table-sidebar", className: "e-table-sidebar" },
            React.createElement("div", { className: "e-table-sidebar-body" },
                React.createElement(TableSidebarCard, { elementId: elementId, isUncommitted: true, recordValue: recordValue, screenId: screenId, value: value, cardDefinition: cardDefinition, level: level }),
                React.createElement(XtremTabs, { tabs: sections, selectedTabId: currentTab, onTabChange: setCurrentTab, inSidebar: true }),
                React.createElement(ConnectedTableSidebarSection, { columns: columns, elementId: elementId, level: level, recordId: recordId, screenId: screenId, section: sidebarLayoutDefinition[currentTab] })))));
}
export const mapStateToProps = (state, props) => {
    const screenDefinition = state.screenDefinitions[props.screenId];
    const value = screenDefinition.values[props.elementId];
    const sidebarLayoutDefinition = getResolvedSidebarLayout({
        layout: props.sidebarDefinition.layout,
        elementId: props.elementId,
        nodeTypes: state.nodeTypes,
        level: props.level,
        screenDefinition,
        value,
    });
    let hasExternalErrors = false;
    const validationErrors = Object.keys(screenDefinition.errors).filter(e => screenDefinition.errors[e].length > 0);
    if (validationErrors.length > 0) {
        const fields = getSidebarNormalFields(sidebarLayoutDefinition).map(field => field.id);
        hasExternalErrors = Boolean(validationErrors.find(field => fields.includes(field)));
    }
    return {
        hasExternalErrors,
        cardDefinition: props.cardDefinition,
        sidebarLayoutDefinition,
        value,
        recordId: props.recordId,
        screenId: props.screenId,
        isUncommitted: true,
        level: props.level,
        isScreenLessThanM: state.browser.lessThan.m,
    };
};
export const mapDispatchToProps = (dispatch, props) => {
    return {
        onConfirm: (addNewRecord = false) => {
            dispatch(xtremRedux.actions.confirmTableSidebar(props.dialogId, addNewRecord));
        },
        onCancel: () => {
            dispatch(xtremRedux.actions.closeTableSidebar(props.dialogId));
        },
    };
};
export const ConnectedTableSidebarBody = connect(mapStateToProps, mapDispatchToProps)(withCollectionValueItemSubscription(TableSidebarBody));
//# sourceMappingURL=table-sidebar-body.js.map