"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConnectedEmployee = getConnectedEmployee;
exports.getIsTimeEntryAdministrator = getIsTimeEntryAdministrator;
exports.getIsTimeEntryEmployee = getIsTimeEntryEmployee;
exports.getIsNegativeTimeSpentAllowed = getIsNegativeTimeSpentAllowed;
exports.getDefaultTimeCategory = getDefaultTimeCategory;
exports.getDefaultUnit = getDefaultUnit;
exports.getIsValidatedDefault = getIsValidatedDefault;
const x3MasterData = require("@sage/x3-master-data");
const xtrem_core_1 = require("@sage/xtrem-core");
const x3SystemUtils = require("@sage/xtrem-x3-system-utils");
const x3ProjectManagement = require("..");
async function getConnectedEmployee(_this) {
    const employee = await _this.$.context.user;
    if (!employee) {
        throw new xtrem_core_1.BusinessRuleError('No username found for current user');
    }
    const projectUser = await _this.$.context.tryRead(x3ProjectManagement.nodes.ProjectUser, {
        employee: employee.userName,
    });
    if (!projectUser) {
        throw new xtrem_core_1.BusinessRuleError('Employee does not exist for time entry');
    }
    else {
        const isActive = await projectUser.isActiveEmployeeOnProjects;
        if (!isActive) {
            throw new xtrem_core_1.BusinessRuleError('Employee is not active on project management');
        }
    }
    return projectUser;
    //
}
async function getIsTimeEntryAdministrator(_this) {
    const connectedEmployee = await _this.connectedEmployee;
    if (!connectedEmployee) {
        return false;
    }
    return connectedEmployee.isTimeEntryAdministrator;
}
async function getIsTimeEntryEmployee(_this) {
    const connectedEmployee = await _this.connectedEmployee;
    if (!connectedEmployee) {
        return false;
    }
    return connectedEmployee.isTimeEntryEmployee;
}
function getIsNegativeTimeSpentAllowed(_this) {
    return x3SystemUtils.nodes.SysGeneralParameter.readParameterValueBoolean(_this.$.context, {
        parameterCode: 'PJMTIMNEG',
    });
}
async function getDefaultTimeCategory(_this) {
    const connectedEmployee = await _this.connectedEmployee;
    if (!connectedEmployee) {
        return null;
    }
    const timeCategory = await connectedEmployee.timeCategory;
    if (timeCategory) {
        return _this.$.context.read(x3ProjectManagement.nodes.TimeCategory, { code: await timeCategory.code });
    }
    return null;
}
async function getDefaultUnit(_this) {
    const connectedEmployee = await _this.connectedEmployee;
    if (!connectedEmployee) {
        return null;
    }
    const site = await connectedEmployee.site;
    if (site) {
        const result = await x3SystemUtils.nodes.SysGeneralParameter.readParameterValueString(_this.$.context, {
            level: 'site',
            code: await site.code,
            parameterCode: 'UNITWORK',
        });
        if (result) {
            return _this.$.context.read(x3MasterData.nodes.UnitOfMeasure, { code: result });
        }
    }
    else {
        const result = await x3SystemUtils.nodes.SysGeneralParameter.readParameterValueString(_this.$.context, {
            parameterCode: 'HOURLYUNIT',
        });
        if (result) {
            return _this.$.context.read(x3MasterData.nodes.UnitOfMeasure, { code: result });
        }
    }
    return null;
}
function getIsValidatedDefault(_this) {
    return x3SystemUtils.nodes.SysGeneralParameter.readParameterValueBoolean(_this.$.context, {
        parameterCode: 'PJMTIMAUTO',
    });
}
//# sourceMappingURL=time-entry-line.js.map