"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SupplierExtension = void 0;
const sageX3MasterData = require("@sage/x3-master-data");
const sageX3System = require("@sage/x3-system");
const xtrem_core_1 = require("@sage/xtrem-core");
const xtrem_x3_gateway_1 = require("@sage/xtrem-x3-gateway");
const sageXtremX3SystemUtils = require("@sage/xtrem-x3-system-utils");
const sageX3FinanceData = require("..");
const joins = {
    referenceJoins: {
        paymentBank: {
            bank: 'paymentBank',
        },
        accountingCode: {
            type() {
                return 'supplier';
            },
            accountingCode: 'accountingCode',
        },
        serviceSupplier: {
            code: 'serviceSupplier',
        },
        accountStructure: {
            code: 'accountStructure',
        },
        expenseAllocation: {
            glossaryId() {
                return 312;
            },
            code: 'expenseAllocation',
        },
        box1099: {
            form1099: 'form1099',
            code: 'box1099',
        },
        payrollInterfaceDistribution: {
            code: 'payrollInterfaceDistribution',
            numberOfLines() {
                return 1;
            },
        },
    },
};
let SupplierExtension = class SupplierExtension extends xtrem_core_1.NodeExtension {
};
exports.SupplierExtension = SupplierExtension;
__decorate([
    xtrem_core_1.decorators.referenceProperty({
        isPublished: true,
        isStored: true,
        isNullable: true,
        columnName: 'PAYBAN',
        columnType: 'string',
        node: () => sageX3FinanceData.nodes.BankAccount,
    })
], SupplierExtension.prototype, "paymentBank", void 0);
__decorate([
    xtrem_core_1.decorators.referenceProperty({
        isPublished: true,
        isStored: true,
        isNullable: true,
        columnName: 'ACCCOD',
        columnType: 'string',
        filters: {
            lookup: {
                type: 'supplier',
            },
            control: {
                type: 'supplier',
            },
        },
        node: () => sageX3FinanceData.nodes.AccountingCode,
    })
], SupplierExtension.prototype, "accountingCode", void 0);
__decorate([
    xtrem_core_1.decorators.referenceProperty({
        isPublished: true,
        isStored: true,
        isNullable: true,
        columnName: 'PRVNUM',
        columnType: 'string',
        node: () => sageX3FinanceData.nodes.ServiceSupplier,
        serviceOptions: () => [sageX3System.serviceOptions.Fee2ActivityCode],
    })
], SupplierExtension.prototype, "serviceSupplier", void 0);
__decorate([
    xtrem_core_1.decorators.decimalProperty({
        isPublished: true,
        isStored: true,
        isNullable: true,
        columnName: 'RITRAT',
        dataType: () => sageXtremX3SystemUtils.datatypes.genericDataTypes.decimalDatatype,
        serviceOptions: () => [sageX3System.serviceOptions.WthmgActivityCode],
    })
], SupplierExtension.prototype, "allowanceRate", void 0);
__decorate([
    xtrem_core_1.decorators.referenceProperty({
        isPublished: true,
        isStored: true,
        isNullable: true,
        columnName: 'DIA',
        columnType: 'string',
        node: () => sageX3FinanceData.nodes.AccountScheme,
    })
], SupplierExtension.prototype, "accountStructure", void 0);
__decorate([
    xtrem_core_1.decorators.referenceProperty({
        isPublished: true,
        isStored: true,
        isNullable: true,
        columnName: 'IPTEXS',
        columnType: 'string',
        filters: {
            lookup: {
                glossaryId: 312,
            },
            control: {
                glossaryId: 312,
            },
        },
        node: () => sageX3System.nodes.MiscellaneousTable,
    })
], SupplierExtension.prototype, "expenseAllocation", void 0);
__decorate([
    xtrem_core_1.decorators.enumProperty({
        isPublished: true,
        isStored: true,
        isNullable: true,
        columnName: 'FRM1099',
        dataType: () => sageX3FinanceData.enums.form1099Datatype,
        serviceOptions: () => [sageX3System.serviceOptions.S1099ActivityCode],
    })
], SupplierExtension.prototype, "form1099", void 0);
__decorate([
    xtrem_core_1.decorators.referenceProperty({
        isPublished: true,
        isStored: true,
        isNullable: true,
        columnName: 'BOX1099',
        columnType: 'string',
        node: () => sageX3FinanceData.nodes.Box1099,
        serviceOptions: () => [sageX3System.serviceOptions.S1099ActivityCode],
    })
], SupplierExtension.prototype, "box1099", void 0);
__decorate([
    xtrem_core_1.decorators.referenceProperty({
        isPublished: true,
        isStored: true,
        isNullable: true,
        columnName: 'BPRDSP',
        columnType: 'string',
        filters: {
            lookup: {
                numberOfLines: 1,
            },
            control: {
                numberOfLines: 1,
            },
        },
        node: () => sageX3FinanceData.nodes.DistributionKey,
        serviceOptions: () => [sageX3System.serviceOptions.MuranActivityCode],
    })
], SupplierExtension.prototype, "payrollInterfaceDistribution", void 0);
__decorate([
    xtrem_core_1.decorators.collectionProperty({
        isPublished: true,
        isVital: true,
        reverseReference: '_denormalizedParent',
        node: () => sageX3FinanceData.nodes.SupplierDimensions,
    })
], SupplierExtension.prototype, "dimensions", void 0);
__decorate([
    xtrem_core_1.decorators.collectionProperty({
        isPublished: true,
        isVital: true,
        reverseReference: '_denormalizedParent',
        node: () => sageX3FinanceData.nodes.SupplierPartnerWithHoldings,
    })
], SupplierExtension.prototype, "partnerWithHoldings", void 0);
__decorate([
    xtrem_core_1.decorators.collectionProperty({
        isPublished: true,
        isVital: true,
        reverseReference: '_denormalizedParent',
        node: () => sageX3FinanceData.nodes.SupplierWithHoldingTaxes,
    })
], SupplierExtension.prototype, "withHoldingTaxes", void 0);
exports.SupplierExtension = SupplierExtension = __decorate([
    xtrem_core_1.decorators.nodeExtension({
        extends: () => sageX3MasterData.nodes.Supplier,
        externalStorageManagerExtension: new xtrem_x3_gateway_1.X3StorageManagerExtension({
            joins,
        }),
    })
], SupplierExtension);
//# sourceMappingURL=supplier-extension.js.map