"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCountOfStockRecords = getCountOfStockRecords;
exports.getDistinctCountOfStockQuantity = getDistinctCountOfStockQuantity;
exports.getDistinctCountOfLocations = getDistinctCountOfLocations;
exports.getDistinctCountOfLots = getDistinctCountOfLots;
exports.getDistinctCountOfSublots = getDistinctCountOfSublots;
exports.getStockUnitCode = getStockUnitCode;
const typesLib = require("@sage/xtrem-decimal");
function getCountOfStockRecords(productSite) {
    return productSite.stock.length;
}
function getDistinctCountOfStockQuantity(productSite) {
    return productSite.stock.reduce(async (accumulator, item) => typesLib.add(accumulator, ((await item.quantityInStockUnit) ?? 0)), 0);
}
async function getDistinctCountOfLocations(productSite) {
    return (await productSite.stock.reduce(async (prevValue, item) => {
        if ((await item.location) && typesLib.strictEq(prevValue.indexOf(await (await item.location).code), -1)) {
            prevValue.push(await (await item.location).code);
        }
        return prevValue;
    }, [])).length;
}
async function getDistinctCountOfLots(productSite) {
    if (typesLib.strictEq((await (await productSite.product).lotManagementMode), 'notManaged')) {
        return 0;
    }
    return (await productSite.stock.reduce(async (prevValue, item) => {
        if ((await item.lot) && typesLib.strictEq(prevValue.indexOf(await item.lot), -1)) {
            prevValue.push(await item.lot);
        }
        return prevValue;
    }, [])).length;
}
async function getDistinctCountOfSublots(productSite) {
    if (typesLib.strictNe((await (await productSite.product).lotManagementMode), 'lotAndSublot')) {
        return 0;
    }
    return (await productSite.stock.reduce(async (prevValue, item) => {
        if ((await item.sublot) && typesLib.strictEq(prevValue.indexOf(await item.sublot), -1)) {
            prevValue.push(await item.sublot);
        }
        return prevValue;
    }, [])).length;
}
async function getStockUnitCode(productSite) {
    return (await (await productSite.product).stockUnit).code;
}
//# sourceMappingURL=product-site-functions.js.map