import { ProductInput } from '@sage/x3-master-data-api';
import { GraphApi, StockChangeInput, StockChangeLineBinding, StockEntryTransaction } from '@sage/x3-stock-api';
import { LotsSites, SerialNumber, Stock, StockJournalBinding } from '@sage/x3-stock-data-api';
import { SupportManagementService } from '@sage/x3-system/lib/client-functions/support-management-service';
import * as ui from '@sage/xtrem-ui';
export declare const mobileApplicationKey = "MobileInventoryStockChangeKey";
type DeepPartial<T> = T extends Object ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : T;
type PartialStockEntryTransaction = DeepPartial<StockEntryTransaction>;
export type inputsStockChange = {
    stockChange: StockChangeInput & {
        id?: string;
    };
    username: string;
    currentLine?: number;
    numberSession?: number;
    started: boolean;
    selectedTransaction?: PartialStockEntryTransaction;
    selectedProduct?: ProductInput;
    destination?: string;
    printingMode?: string;
};
export declare enum PrintingModeEnum {
    noPrint = 1,
    stockLabel = 2,
    substituteValue3 = 3,
    transfertDocument = 4,
    analysisDocument = 5,
    createdContainerLabel = 6,
    stockLabelAndCreatedContainerLabel = 7
}
interface StockChangeLineWithQuantityMoved extends StockChangeLineBinding {
    quantityMoved: number;
}
interface StockJournalWithQuantityMoved extends StockJournalBinding {
    quantityMoved: number;
}
export declare class MobileInternalStockChange extends SupportManagementService<GraphApi> {
    private _transactions;
    private _transaction;
    private _notifier;
    private _mobileSettings;
    private _stockFieldSettings;
    private _numberSession;
    private _productSite;
    private _packingUnits;
    private _selectedStockManagementRules;
    private _locationProducts;
    private _previousQuantity;
    private _previousSerialNumber;
    private _previousEndingSerialNumber;
    private _licensePlateNumber;
    createButton: ui.PageAction;
    nextButton: ui.PageAction;
    CancelButton: ui.PageAction;
    SelectButton: ui.PageAction;
    addSerialRangeButton: ui.PageAction;
    transactionSection: ui.containers.Section;
    transactionBlock: ui.containers.Block;
    customizationInternalStockChangeHeaderBlock: ui.containers.Block;
    effectiveDate: ui.fields.Date;
    stockSite: ui.fields.Reference;
    transaction: ui.fields.DropdownList;
    destinationCode: ui.fields.Text;
    printingMode: ui.fields.Text;
    fromSection: ui.containers.Section;
    fromBlock: ui.containers.Block;
    locationSelected: ui.fields.Reference;
    private readonly _onChange_locationSelected;
    productSelected: ui.fields.Reference;
    private readonly _onChange_productSelected;
    toSection: ui.containers.Section;
    toBlock: ui.containers.Block;
    mainLocationDestination: ui.fields.Reference;
    private readonly _onChange_mainLocationDestination;
    mainStatusDestination: ui.fields.Select;
    private readonly _onChange_mainStatusDestination;
    mainIdentifier1Destination: ui.fields.Text;
    private readonly _onChange_mainIdentifier1Destination;
    mainIdentifier2Destination: ui.fields.Text;
    private readonly _onChange_mainIdentifier2Destination;
    stockChangeLinesSection: ui.containers.Section;
    stockChangeLinesBlock: ui.containers.Block;
    stockChangeLines: ui.fields.NestedGrid<[StockChangeLineWithQuantityMoved, StockJournalWithQuantityMoved]>;
    private _init;
    private getLocationInMobileSettings;
    private _disablePage;
    private _initSite;
    private _initPageDetail;
    private _getStockStatus;
    private _initTransaction;
    private _setTransaction;
    stockPanelSection: ui.containers.Section;
    detailPanelSection: ui.containers.Section;
    stockBlock: ui.containers.Block;
    detailsBlock: ui.containers.Block;
    quantityBlock: ui.containers.Block;
    customizationInternalStockChangeLinesBlock: ui.containers.Block;
    customizationInternalStockChangeDetailsBlock: ui.containers.Block;
    serialNumberBlock: ui.containers.Block;
    gridBlock: ui.containers.GridRowBlock;
    listSerialNumberBlock: ui.containers.Block;
    productCode: ui.fields.Text;
    productDescription: ui.fields.Text;
    licensePlateNumberFilter: ui.fields.Reference;
    private readonly _onChange_licensePlateNumberFilter;
    locationFilter: ui.fields.Reference;
    private readonly _onChange_locationFilter;
    lotFilter: ui.fields.Reference<LotsSites>;
    private readonly _onChange_lotFilter;
    sublotFilter: ui.fields.Reference<LotsSites>;
    private readonly _onChange_sublotFilter;
    serialNumberFilter: ui.fields.Reference<SerialNumber>;
    private readonly _onChange_serialNumberFilter;
    statusFilter: ui.fields.Select;
    private readonly _onChange_statusFilter;
    packingUnitFilter: ui.fields.Select;
    packingUnitToStockUnitConversionFactorFilter: ui.fields.Numeric;
    identifier1Filter: ui.fields.Text;
    private readonly _onChange_identifier1Filter;
    identifier2Filter: ui.fields.Text;
    private readonly _onChange_identifier2Filter;
    stockCustomField1Filter: ui.fields.Text;
    private readonly _onChange_stockCustomField1Filter;
    stockCustomField2Filter: ui.fields.Text;
    private readonly _onChange_stockCustomField2Filter;
    stock: ui.fields.Table<Stock>;
    stockDetails: ui.fields.DetailList<Stock>;
    quantityToMove: ui.fields.Numeric;
    private readonly _onChange_quantityToMove;
    locationDestination: ui.fields.Reference;
    private readonly _onChange_locationDestination;
    statusDestination: ui.fields.Select;
    private readonly _onChange_statusDestination;
    packingUnitDestination: ui.fields.DropdownList;
    private readonly _onChange_packingUnitDestination;
    packingUnitToStockUnitConversionFactorDestination: ui.fields.Numeric;
    identifier1Destination: ui.fields.Text;
    private readonly _onChange_identifier1Destination;
    identifier2Destination: ui.fields.Text;
    private readonly _onChange_identifier2Destination;
    startingSerialNumber: ui.fields.Reference<SerialNumber>;
    private readonly _onChange_startingSerialNumber;
    endingSerialNumber: ui.fields.Text;
    private readonly _onChange_endingSerialNumber;
    private _onRowClick;
    private _onRowSelect;
    _stockId: ui.fields.Text;
    serialNumberLines: ui.fields.Table<any>;
    private _setSelectButton;
    private _validateSerialNumber;
    private _getQuantityInPackingUnitOrigin;
    private _getQuantityInPackingUnitRest;
    private _getStockChangeLine;
    private _getQuantityToMove;
    private _getLocationDestination;
    private _getPackingUnitToStockUnitConversionFactorDestination;
    private _getIdentifier1Destination;
    private _getIdentifier2Destination;
    private _getPackingUnitDestination;
    private _getStatusDestination;
    private _calculateEndingSerialNumber;
    private onChangeBody;
    private _getProductSite;
    private _getStock;
    private _getLocationProducts;
    private _getSidebarInternalStockChangeLine;
    private _getSidebarInternalStockChangeDetail;
    private getCustomizationInternalStockChangeLines;
    private getCustomizationInternalStockChangeDetails;
    /**
     *
     * Technical composite data methods
     *
     */
    /**
     * Initialize ControlManager
     * @returns true when ControlManager is usable
     */
    private _initControlManager;
    /**
     *
     * Technical screen management methods
     *
     */
    /**
     *  @returns the active section
     */
    private _getActiveSection;
    /**
     *
     * @param newSection
     * @returns  the old active section
     */
    private _setActiveSection;
    private _resetFieldFilters;
}
export {};
//# sourceMappingURL=mobile-internal-stock-change.d.ts.map