import { AutomaticJournal } from '@sage/x3-finance-data-api';
import { Container, MajorVersionStatus, Product, ProductInput, ProductVersion } from '@sage/x3-master-data-api';
import { GraphApi, MiscellaneousReceiptInput, MiscellaneousReceiptLineBinding, StockEntryTransaction } from '@sage/x3-stock-api';
import { LicensePlateNumber, Location, LotsSites, StockJournalBinding, Warehouse } from '@sage/x3-stock-data-api';
import { Site } from '@sage/x3-system-api-partial';
import * as ui from '@sage/xtrem-ui';
export declare const mobileApplicationKey = "MobileMiscellaneousReceiptKey";
export type DeepPartial<T> = T extends Object ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : T;
type PartialStockEntryTransaction = DeepPartial<StockEntryTransaction>;
export type inputs = {
    miscellaneousReceipt: MiscellaneousReceiptInput & {
        id: string;
    };
    username: string;
    started: boolean;
    selectedTransaction: PartialStockEntryTransaction;
    selectedProduct?: ProductInput;
    destination?: string;
};
export type packingUnit = {
    node: {
        packingUnit: {
            code: string;
            numberOfDecimals: number;
            _id: string;
        };
        packingUnitToStockUnitConversionFactor: string;
        isPackingFactorEntryAllowed: boolean;
        _id: string;
    };
};
export declare class MobileMiscellaneousReceipt extends ui.Page<GraphApi> {
    private _notifier;
    private _transactions;
    private _numberOfDecimalList;
    private _isLocationPreloaded;
    private _packingUnits;
    private _productSite;
    private _miscellaneousReceiptLines;
    private _selectedTransaction;
    private _selectedLocation;
    private _selectedStockManagementRules;
    private _newDetail;
    private _oldSupplierLotValue;
    private _majorVersion;
    private _lots;
    private _fieldsData;
    stockSite: ui.fields.Reference<Site, MobileMiscellaneousReceipt>;
    createButton: ui.PageAction;
    addButton: ui.PageAction;
    mainSection: ui.containers.Section;
    transactionBlock: ui.containers.Block;
    customizationMiscellaneousReceiptHeaderBlock: ui.containers.Block;
    effectiveDate: ui.fields.Date<MobileMiscellaneousReceipt>;
    transaction: ui.fields.DropdownList<NonNullable<PartialStockEntryTransaction['code']>, MobileMiscellaneousReceipt>;
    entryType: ui.fields.Select<'miscellaneousReceipt', MobileMiscellaneousReceipt>;
    id: ui.fields.Text<MobileMiscellaneousReceipt>;
    destination: ui.fields.Text<MobileMiscellaneousReceipt>;
    stockMovementCode: ui.fields.Reference;
    stockMovementGroup: ui.fields.Reference;
    stockAutomaticJournal: ui.fields.Reference<AutomaticJournal, MobileMiscellaneousReceipt>;
    productBlock: ui.containers.Block;
    product: ui.fields.Reference<Product, MobileMiscellaneousReceipt>;
    defaultBlock: ui.containers.Block;
    customizationMiscellaneousReceiptLinesBlock: ui.containers.Block;
    customizationMiscellaneousReceiptDetailsBlock: ui.containers.Block;
    warehouseDestination: ui.fields.Reference<Warehouse, MobileMiscellaneousReceipt>;
    packingUnit: ui.fields.DropdownList<string, MobileMiscellaneousReceipt>;
    quantityInPackingUnit: ui.fields.Numeric<MobileMiscellaneousReceipt>;
    packingUnitToStockUnitConversionFactorDestination: ui.fields.Numeric<MobileMiscellaneousReceipt>;
    status: ui.fields.DropdownList<string, MobileMiscellaneousReceipt>;
    containerDestination: ui.fields.Reference<Container, MobileMiscellaneousReceipt>;
    licensePlateNumber: ui.fields.Reference<LicensePlateNumber, MobileMiscellaneousReceipt>;
    suggestedLocation: ui.fields.Text<MobileMiscellaneousReceipt>;
    location: ui.fields.Reference<Location, MobileMiscellaneousReceipt>;
    dummyLocation: ui.fields.Text<MobileMiscellaneousReceipt>;
    serialNumber: ui.fields.Text<MobileMiscellaneousReceipt>;
    supplierLot: ui.fields.Text<MobileMiscellaneousReceipt>;
    lot: ui.fields.FilterSelect<LotsSites, MobileMiscellaneousReceipt>;
    sublot: ui.fields.Text<MobileMiscellaneousReceipt>;
    majorVersion: ui.fields.Reference<MajorVersionStatus, MobileMiscellaneousReceipt>;
    minorVersion: ui.fields.Reference<ProductVersion, MobileMiscellaneousReceipt>;
    potencyDestination: ui.fields.Numeric<MobileMiscellaneousReceipt>;
    expirationDate: ui.fields.Date<MobileMiscellaneousReceipt>;
    useByDate: ui.fields.Date<MobileMiscellaneousReceipt>;
    lotCustomField1: ui.fields.Text<MobileMiscellaneousReceipt>;
    lotCustomField2: ui.fields.Text<MobileMiscellaneousReceipt>;
    lotCustomField3: ui.fields.Numeric<MobileMiscellaneousReceipt>;
    lotCustomField4: ui.fields.Date<MobileMiscellaneousReceipt>;
    identifier1: ui.fields.Text<MobileMiscellaneousReceipt>;
    identifier2: ui.fields.Text<MobileMiscellaneousReceipt>;
    stockHeaderSection: ui.containers.Section;
    stockLineBlock: ui.containers.Block;
    productHeader: ui.fields.Text<MobileMiscellaneousReceipt>;
    localizedDescription1Header: ui.fields.Text<MobileMiscellaneousReceipt>;
    private _initFieldsDestination;
    private _lotManagement;
    private _initPackingUnitFields;
    private _miscellaneousFieldsManagement;
    private _getStockStatus;
    private _getNumberOfDecimals;
    private _getWarehouseFromLocation;
    private _getDefaultLocation;
    private _getLots;
    private _getLotValues;
    private _setLotValues;
    private _initLotValues;
    private _isEmptyLpnAndContainerValues;
    private _isZeroQuantityValue;
    private _getNextField;
    private _isLotProvided;
    private _getMinorVersions;
    private _manageLicensePlateNumberLocation;
    private _addMiscLineAndStockDetails;
    miscellaneousReceiptLinesBlock: ui.containers.Block;
    miscellaneousReceiptLines: ui.fields.NestedGrid<[MiscellaneousReceiptLineBinding, StockJournalBinding]>;
    private _init;
    private _initSite;
    private _initTransaction;
    private _getIsLocationPreloaded;
    private _disablePage;
    private _initStockJournalLotValue;
    private getSidebarData;
    private _getSidebarMiscellaneousReceiptLine;
    private _getSidebarStockJournal;
    private getcustomizationMiscellaneousReceiptLines;
    private getcustomizationMiscellaneousReceiptDetails;
    private _initPackingUnitToStockUnitConversionFactorDestination;
}
export {};
//# sourceMappingURL=mobile-miscellaneous-receipt.d.ts.map