import { AutomaticJournal } from '@sage/x3-finance-data-api';
import { GraphApi, PurchaseReceiptLineBinding } from '@sage/x3-purchasing-api';
import { Lot, StockJournalBinding } from '@sage/x3-stock-data-api';
import { Site } from '@sage/x3-system-api';
import { SupportManagementService } from '@sage/x3-system/lib/client-functions/support-management-service';
import * as ui from '@sage/xtrem-ui';
export type DeepPartial<T> = T extends Object ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : T;
export declare const mobileApplicationKey = "MobilePurchaseReceiptKey";
interface StockJournalClosePoLine extends StockJournalBinding {
    closePoLine: string;
    remainingQuantityInStockUnit: number;
    containerDetail: string;
}
export declare class MobilePurchaseReceipt extends SupportManagementService<GraphApi> {
    private _entryTransactionMap;
    private _selectedEntryTransaction;
    private _productSearchCriteria1;
    private _productSearchCriteria2;
    private _purchaseShipmentId;
    private _purchaseShipmentLineNumber;
    private _shipmentLines;
    private _purchaseShipmentIds;
    private _isLocationPreloaded;
    private _productSite;
    private _packingUnits;
    private _isOverReceiptAllowed;
    private _purchaseStockManagementRules;
    private _purchaseOrderLine;
    private _supplierProduct;
    private _purchaseShipmentLine;
    private _effectiveDate;
    private _quantityToReceiveNoRounded;
    private _quantityToReceiveRounded;
    private _remainingQuantityNoRoundedInPackingUnit;
    private _remainingQuantityRoundedInPackingUnit;
    private _remainingQuantityInitialInStockUnit;
    private _remainingQuantityInitialInOrderUnit;
    private _locationDetail;
    private _containerDetail;
    private _lots;
    private _directReceiptAllowed?;
    receiptSite: ui.fields.Reference<Site, MobilePurchaseReceipt>;
    createButton: ui.PageAction;
    addButton: ui.PageAction;
    mainSection: ui.containers.Section;
    productBlock: ui.containers.Block;
    customizationPurchaseReceiptHeaderBlock: ui.containers.Block;
    destinationBlock: ui.containers.Block;
    customizationPurchaseReceiptLinesBlock: ui.containers.Block;
    customizationPurchaseReceiptDetailsBlock: ui.containers.Block;
    shipmentBlock: ui.containers.Block;
    receiptBlock: ui.containers.Block;
    id: ui.fields.Text<MobilePurchaseReceipt>;
    receiptDate: ui.fields.Date;
    transaction: ui.fields.DropdownList;
    destination: ui.fields.Text<MobilePurchaseReceipt>;
    document: ui.fields.Text<MobilePurchaseReceipt>;
    stockMovementCode: ui.fields.Reference;
    stockAutomaticJournal: ui.fields.Reference<AutomaticJournal, MobilePurchaseReceipt>;
    legalCompany: ui.fields.Label;
    purchaseOrder: ui.fields.Reference;
    supplier: ui.fields.Reference;
    supplierPackingSlipLink: ui.fields.Link;
    supplierPackingSlip: ui.fields.Text;
    product: ui.fields.Reference;
    productFromPurchaseOrder: ui.fields.Reference;
    receiptUnit: ui.fields.DropdownList;
    receiptUnitCode: ui.fields.Label;
    previousReceiptUnit: ui.fields.Label;
    previousReceiptUnitCode: ui.fields.Label;
    quantityReceived: ui.fields.Numeric<MobilePurchaseReceipt>;
    previousQuantityToReceive: ui.fields.Numeric;
    destinationRemainingQuantityInPackingUnit: ui.fields.Numeric;
    destinationRemainingQuantityInStockUnit: ui.fields.Numeric;
    packingUnitToStockUnitConversionFactor: ui.fields.Numeric;
    status: ui.fields.DropdownList;
    destinationContainer: ui.fields.Reference;
    licensePlateNumber: ui.fields.Reference;
    suggestedLocation: ui.fields.Text;
    location: ui.fields.Reference;
    warehouse: ui.fields.Text;
    serialNumber: ui.fields.Text;
    supplierLot: ui.fields.Text;
    previousSupplierLot: ui.fields.Label;
    lot: ui.fields.FilterSelect<Lot>;
    svgLot: ui.fields.Text;
    sublot: ui.fields.Text;
    majorVersion: ui.fields.Reference;
    minorVersion: ui.fields.Reference;
    potency: ui.fields.Numeric;
    expirationDate: ui.fields.Date;
    useByDate: ui.fields.Date;
    calculatedExpirationDate: ui.fields.Date;
    lotCustomField1: ui.fields.Text;
    lotCustomField2: ui.fields.Text;
    lotCustomField3: ui.fields.Numeric;
    lotCustomField4: ui.fields.Date;
    identifier1: ui.fields.Text;
    identifier2: ui.fields.Text;
    closePoLine: ui.fields.DropdownList;
    lines: ui.fields.NestedGrid<[PurchaseReceiptLineBinding, StockJournalClosePoLine]>;
    shipments: ui.fields.Table<any>;
    /**
     *
     * Methods section
     *
     *
     */
    private _init;
    /**
     * Initialize ControlManager
     * @returns true when ControlManager is usable
     */
    private _initControlManager;
    /**
     * Get dictionary field supported
     *  @returns DictionaryFieldSupported
     */
    private _getDictionaryFieldSupported;
    private _getLegalCompany;
    private _getEntryTransactionOptions;
    private _disablePage;
    private _getProductSearch;
    private _initTransaction;
    private _clearPage;
    private _disableDestinationFields;
    private _initializePage;
    private _initPackingUnitFields;
    private _initLotFields;
    private _initVersionFields;
    private _miscellaneousFields;
    private _getDefaultValue;
    private _getShipments;
    private _readShipmentLines;
    private _cleanShipmentLines;
    private getProductSite;
    private getPurchaseOrderLine;
    private getSupplierProduct;
    private getPurchaseShipmentLine;
    private _addLineAndStockDetails;
    private readonly _onChange_serialNumber;
    private _getNextField;
    private _getLots;
    private _getLotValues;
    private _setLotValues;
    private _initLotValues;
    private _validate;
    private _isFieldInvalid;
    private _isEmptyLpnAndContainerValues;
    private _isZeroQuantityValue;
    private _getMinorVersions;
    private _getStockStatus;
    private _getDefaultLocation;
    private calculateRemainingQuantity;
    private calculCurrentQuantityInStockUnitReceived;
    private getSidebarData;
    private _getSidebarPurchaseReceiptLine;
    private _getSidebarStockJournal;
    private getCustomizationPurchaseReceiptLines;
    private getCustomizationPurchaseReceiptDetails;
    /**
     *
     * Technical screen management methods
     *
     */
    /**
     *  @returns the active section
     */
    private _getActiveSection;
    /**
     *
     * @param newSection
     * @returns  the old active section
     */
    private _setActiveSection;
    /**
     * @returns true if the active section is the destination section
     */
    private _isMandatoryDestination;
}
export {};
//# sourceMappingURL=mobile-purchase-receipt.d.ts.map