import { WorkOrderOperationTrackingLineBinding as TimeTrackingLineBinding, WorkOrderOperationLine } from '@sage/x3-manufacturing-api';
import { RoutingHeader } from '@sage/x3-manufacturing-api-partial';
import { GraphApi } from '@sage/x3-manufacturing-data-api';
import { decimal, ExtractEdges } from '@sage/xtrem-client';
import * as ui from '@sage/xtrem-ui';
import { PartialCollectionValueWithIds } from '@sage/xtrem-ui/build/lib/component/types';
import { TransactionList } from '../client-functions/get-entry-transaction';
interface TimeTrackingLine extends TimeTrackingLineBinding {
    enteredSetupTimeHours?: number;
    enteredSetupTimeMinutes?: number;
    enteredRunTimeHours?: number;
    enteredRunTimeMinutes?: number;
    operationDescription?: string;
    expectedQuantity?: number;
    completedQuantity?: number;
}
export declare class MobileTimeTracking extends ui.Page<GraphApi> {
    private transactionsList;
    mainSection: ui.containers.Section;
    transactionBlock: ui.containers.Block;
    trackingDate: ui.fields.Date;
    productionSite: ui.fields.Reference;
    transaction: ui.fields.Select;
    headerBlock: ui.containers.Block;
    trackingNumber: ui.fields.Text<MobileTimeTracking>;
    customTimeTrackingHeaderBlock: ui.containers.Block;
    employeeId: ui.fields.Reference;
    workOrder: ui.fields.Reference;
    releaseUOM: ui.fields.Text;
    releaseTimeUnit: ui.fields.Text;
    unplannedOperations: ui.fields.Checkbox;
    stdOperation: ui.fields.Reference;
    operationLine: ui.fields.Reference;
    stdOperationDescription: ui.fields.Text;
    unplannedOperationsLine: ui.fields.Numeric;
    detailBlock: ui.containers.Block;
    customTimeTrackingDetailBlock: ui.containers.Block;
    expectedWorkCenter: ui.fields.Reference;
    timeUnit: ui.fields.Text;
    stockUnit: ui.fields.Text;
    remainingQuantity: ui.fields.Numeric;
    rejectedQuantity: ui.fields.Numeric;
    setupTime: ui.fields.Numeric;
    runTime: ui.fields.Numeric;
    enteredSetupTimeHours: ui.fields.Numeric;
    enteredSetupTimeMinutes: ui.fields.Numeric;
    enteredRunTimeHours: ui.fields.Numeric;
    enteredRunTimeMinutes: ui.fields.Numeric;
    close: ui.fields.Checkbox;
    trackingLinesBlock: ui.containers.Block;
    workOrderOperationTrackingLines: ui.fields.Table<TimeTrackingLine>;
    createButton: ui.PageAction;
    addButton: ui.PageAction;
    /** Functions Validation and Fields Management */
    initPage(): Promise<void>;
    setMandatoryFields(transactions: any[]): Promise<boolean | undefined>;
    setEntryTransaction(transaction: any[], transactionIsDisabled: boolean, allFieldsDisabled: boolean): void;
    /**
     * Is the employee id mandatory
     * @param transactions
     * @param currentTransaction
     * @returns boolean
     */
    isEmployeeMandatory(transactions: TransactionList[], currentTransaction: string): Promise<boolean>;
    /**
     * Is the employee id field to be hidden
     * @param transactions
     * @param currentTransaction
     * @returns boolean
     */
    isEmployeeHidden(transactions: TransactionList[], currentTransaction: string): Promise<boolean>;
    /** Function returns whether unplanned operations checkbox is hidden based on unplanned operation flag
        in the entry transaction - True | False */
    isUnplannedOperationsHidden(transactions: TransactionList[], currentTransaction: string): Promise<boolean>;
    setOperationFieldsDisabledStatus(): void;
    isUnplannedOperationsEnabled(): void;
    /**
     * Function to disable create button if no lines are present in the table
     * @param linesLength
     * @returns boolean
     */
    toggleCreateButton(linesLength: number): boolean;
    setCurrentEmployee(): Promise<void>;
    getDate(): Promise<string>;
    /** Function to set the default employee for the user */
    setDefaultEmployee(): Promise<number | undefined>;
    getWorkOrderRoutingList(): Promise<ExtractEdges<RoutingHeader>[]>;
    /** function to test if operation can be tracked - tracking is only permitted if previous operation
     *  has already been tracked and exists X3 or has been added to the grid pending creation */
    isPreviousOperationTracked(operationNumber: number, workOrder: any, operationMileStoneType: string | undefined): Promise<boolean>;
    /** function to test if an operation number exists on the mobile page 1 tracking grid */
    isOperationOnTrackingGrid(operationNumber: number | undefined, workOrderNumber: number): Promise<boolean>;
    /** function to test if the previous operation for the current operation has been tracking in X3 */
    isPreviousOperationTrackedDB(opNumber: number, opList: ExtractEdges<WorkOrderOperationLine>[]): Promise<boolean | undefined>;
    infoDialogOption(): ui.dialogs.DialogOptions;
    successDialogOption(): ui.dialogs.DialogOptions;
    errorDialogOption(): ui.dialogs.DialogOptions;
    /** function to return the milestone type for an operation */
    getOperationMilestoneType(operation: number, woNumber: string): Promise<string>;
    /** Function to get release time unit for selected work order **/
    getReleaseTimeUnit(): Promise<string>;
    /** Function to get release unit for selected work order **/
    getReleaseUOM(): Promise<string>;
    /** Function to return the previous operation number */
    getPreviousOperation(operation: number, woNumber: string): Promise<number | undefined>;
    /** function verify if the time and quantity values enter are permitted - True | False
     * @param calledFrom
     * @returns boolean
     */
    isTimeAndQuantityValid(calledFrom: string): Promise<boolean>;
    /** function to set the Close field - yes/no based on the quantity being tracked */
    setCloseField(): Promise<void>;
    /**
     * clearFields()
     */
    clearFields(): void;
    /** Initialize-set detail block field values */
    setDetailDefaultValues(): Promise<void>;
    /**
     * Set the stock and time units based on the operation method
     *
     */
    setStockTimeUnits(): Promise<void>;
    /** Set the scale for numeric field based on their unit of measure */
    setScaleForNumericFields(stockUnit: string): Promise<void>;
    /** Set the work centre */
    setWorkCenter(workCenter: string): Promise<void>;
    /** set the remaining quantity value. Expected qty minus the completed qty
     *  if completed exceeds expected then set qty to zero */
    getRemainingQuantity(): Promise<number>;
    /**Calculate the remaining quantity in X3 database
     * @param expectedQuantity
     * @param completedQuantity
     * @returns number
     */
    remainingQtyInX3Database(expectedQuantity: number, completedQuantity: number): Promise<number>;
    /** Calculate the total quantities tracked for the work order - operation
     * @param trackingLines
     * @param workOrder
     * @param operationNumber
     * @returns number
     */
    qtyTrackedOnDeviceOnly(trackedLines: PartialCollectionValueWithIds<TimeTrackingLine>[], workOrderNumber: string, operationNumber: number): Promise<number>;
    /** Function coverts the setup time entered by the user to operation time unit
     *  updates runtime page field with new value return: true | false was calculation successfully
     */
    setActualRunTime(): Promise<boolean>;
    /** Function coverts the setup time entered by the user to operation time unit
     *  updates setuptime page field with new value return: true | fales was calculation succefully
     */
    setActualSetupTime(): Promise<boolean>;
    /**
     * Automatic closing percentage for expected work center & site
     * @param workCenter
     * @param site
     * @returns
     */
    getAutomaticClosingPercent(workCenter: string, site: string): Promise<decimal>;
    /** Function to add the custom block to the time tracking lines table
     * @returns custom block details item:value
     */
    private getCustomTimeTrackingDetails;
    /** Function to get the custom detail fields from the time tracking lines table
     *
     * @returns
     */
    private getCustomTimeTrackingLines;
    private getCustomSidebarTimeTrackingLine;
}
export {};
//# sourceMappingURL=mobile-time-tracking.d.ts.map