import HttpStatusCode from "../constants/HttpStatusCode";
import { BackendSettings } from "../contexts/BackendContext";
import { FetchMethod, UpdateMethod } from "../types/RequestMethod";
import { RequestReason } from "../types/RequestReason";
export interface RequestHeaders {
    [key: string]: string;
}
export interface ResponseHeaders {
    [key: string]: string;
}
export interface BackendServiceParams {
    [key: string]: string;
}
export interface RetryOptions {
    maxRetries: number;
    allowedStatusCodes: HttpStatusCode[];
    retryAfterIfNoHeader?: number;
}
type TBackendFetchResult<TResponseData> = {
    headers: RequestHeaders;
    data: TResponseData;
};
export declare class BackendError extends Error {
    httpStatusCode: number;
    headers: ResponseHeaders;
    constructor(message: string, httpStatusCode: number, headers: ResponseHeaders);
}
export declare const paramsToString: (params: BackendServiceParams | undefined | null) => string;
declare class BackendFetch {
    backendSettings: BackendSettings;
    constructor(backendSettings: BackendSettings);
    setBackendSettings(settings: BackendSettings): void;
    _fetchFromBackend<TResponseData, TRequestData>(endpoint: string, params?: BackendServiceParams, method?: FetchMethod, data?: TRequestData, reason?: RequestReason, retryOptions?: RetryOptions): Promise<TBackendFetchResult<TResponseData>>;
    fetchFromBackend<TResponseData, TRequestData>(endpoint: string, params?: BackendServiceParams, method?: FetchMethod, data?: TRequestData, reason?: RequestReason, retryOptions?: RetryOptions): Promise<TBackendFetchResult<TResponseData>>;
    updateBackend<TData, TResponse>(endpoint: string, data: TData, method?: UpdateMethod, reason?: RequestReason, retryOptions?: RetryOptions): Promise<TResponse>;
    getRequestHeaders(_endpoint: string, _requestMethod: UpdateMethod | FetchMethod, _reason: RequestReason): Promise<RequestHeaders>;
    getBackendEndpointUrl(_endpoint: string): string;
    getExtraRequestParams(_endpoint: string): BackendServiceParams;
}
export default BackendFetch;
