import { BarChartData, BarChartOptions, LineChartData, LineChartOptions, PieChartData, PieChartOptions } from "@sageai/chartist";
import { UUIDType } from "../../../types/SessionMessage";
import { DetailSeparatorBehavior, GenericTableCellKind, IGenericTableCell, IGenericTableCellBase, IMessagePartBase, IMessagePartChartCopilotOptions, ITableIcon, ITableLink, MessagePartHyperLinkStyle, MessagePartHyperLinkType, MessagePartTableRowKind, RecentInvoiceStatus, TableCellAlignment, TableCellStyle, TableCellTextWrapping, TableCellWidth, TableIconKind, TableIconPosition } from "../../../types/SessionMessageParts";
import DataRoleCounter from "./DataRoleCounter";
import { SageIconType } from "../../../types/SageIconType";
import { LinkIconColor } from "../../../components/link/AiKitLink.styles";
export declare const parseSessionMessageDate: (dateStr: string) => Date;
interface IMessagePartBaseJson {
    message_part_id: string;
    message_id: string;
    part_index: number;
    kind: string;
    created_at: string;
}
interface IMessagePartTextJson extends IMessagePartBaseJson {
    kind: "text";
    text: string;
    lhs_icon?: SageIconType;
    lhs_icon_color?: LinkIconColor;
}
interface IMessagePartExplanationJson extends IMessagePartBaseJson {
    kind: "explanation";
    text: string;
}
interface IMessagePartSummaryJson extends IMessagePartBaseJson {
    kind: "summary";
    text: string;
}
interface IMessagePartHyperlinkJson extends IMessagePartBaseJson {
    kind: "hyperlink";
    text: string;
    url: string;
    link_type?: MessagePartHyperLinkType;
    link_style?: MessagePartHyperLinkStyle;
    show_icon?: boolean;
    icon?: SageIconType;
    icon_color?: LinkIconColor;
}
interface IMessagePartDetailSeparatorJson extends IMessagePartBaseJson {
    kind: "detail_separator";
    text: string;
    link_style?: MessagePartHyperLinkStyle;
    show_icon?: boolean;
    behavior?: DetailSeparatorBehavior;
}
interface IMessagePartIntacctCloseHeadingJson extends IMessagePartBaseJson {
    kind: "intacct_close_heading";
    text: string;
    update_ts: string;
}
interface IStyledPromptJson {
    prompt: string;
    alt_display_text?: string;
    style: MessagePartHyperLinkStyle;
    icon: SageIconType | undefined;
    icon_color: LinkIconColor | undefined;
    data_role?: string;
}
interface IMessagePartPromptJson extends IMessagePartBaseJson {
    kind: "prompt";
    prompts: (string | IStyledPromptJson)[];
}
interface IMessagePartChartJson extends IMessagePartBaseJson {
    kind: "chart";
    chart_data: IMessagePartChartDataJson;
}
interface IMessagePartBarChartDataJson {
    kind: "bar";
    data: BarChartData;
    options?: BarChartOptions;
    copilot_options?: IMessagePartChartCopilotOptions;
}
interface IMessagePartLineChartDataJson {
    kind: "line";
    data: LineChartData;
    options?: LineChartOptions;
    copilot_options?: IMessagePartChartCopilotOptions;
}
interface IMessagePartPieChartDataJson {
    kind: "pie";
    data: PieChartData;
    options?: PieChartOptions;
    copilot_options?: IMessagePartChartCopilotOptions;
}
type IMessagePartChartDataJson = IMessagePartBarChartDataJson | IMessagePartLineChartDataJson | IMessagePartPieChartDataJson;
interface IMessagePartTableJson extends IMessagePartBaseJson {
    kind: "table";
    table_data: ITableDataJson;
}
interface IMessagePartTitleJson extends IMessagePartBaseJson {
    kind: "title";
    text: string;
}
interface IMessagePartSubmitBaseJson extends IMessagePartBaseJson {
    key: string;
    label?: string;
    required?: boolean;
}
interface IMessagePartSubmitTextJson extends IMessagePartSubmitBaseJson {
    kind: "submit_text";
}
interface IMessagePartSubmitSelectJson extends IMessagePartSubmitBaseJson {
    kind: "submit_select";
    options: {
        label: string;
        value: string;
    }[];
    placeholder?: string;
}
interface IMessagePartSubmitJson extends IMessagePartBaseJson {
    kind: "submit";
    prompt_text: string;
    button_text: string;
}
interface IMessagePartCustom1Json extends IMessagePartBaseJson {
    kind: "copilot_custom_1_part";
    text: string;
}
interface IMessagePartCustom2Json extends IMessagePartBaseJson {
    kind: "copilot_custom_2_part";
    text: string;
}
interface IMessagePartPollInsightsJson extends IMessagePartBaseJson {
    kind: "poll_insights";
    stop_condition: "new_insight";
    initial_wait_seconds: number;
    wait_seconds: number;
    timeout_seconds: number;
}
export interface IMessagePartProxiedQueryDefinitionJson extends IMessagePartBaseJson {
    kind: "proxied_query_definition";
    method: "POST" | "GET";
    url: string;
    headers?: {
        [key: string]: string;
    } | null;
    params?: {
        [key: string]: string;
    } | null;
    body?: object | null;
    state?: object | null;
    timeout_seconds?: number | null;
}
type ITableDataJson = IRecentInvoicesTableDataJson | IUnallocatedReceiptsTableDataJson | IGenericTableDataJson;
export interface IRecentInvoicesTableDataJson {
    kind: "recent_invoices_table";
    rows: IRecentInvoicesTableRowJson[];
}
export interface IUnallocatedReceiptsTableDataJson {
    kind: "unallocated_receipts_table";
    rows: IUnallocatedReceiptsTableRowJson[];
}
interface IGenericTableDataJson {
    kind: "generic_table";
    headings: IGenericTableHeadingJson[];
    rows: IGenericTableRowJson[];
}
interface ITableRowBaseJson {
    kind: MessagePartTableRowKind;
    row_id?: string;
}
export interface IRecentInvoicesTableRowJson extends ITableRowBaseJson {
    kind: "recent_invoices_row";
    invoice_date: string;
    invoice_link: ITableLinkJson;
    total_str: string;
    status: RecentInvoiceStatus;
    due_date?: string;
    status_detail?: string;
    paid_date: string | null;
}
export interface IUnallocatedReceiptsTableRowJson extends ITableRowBaseJson {
    kind: "unallocated_receipts_row";
    total_str: string;
    receipt_link: ITableLinkJson;
    allocate_link: ITableLinkJson | null;
    receipt_date: string;
    outstanding_str: string;
}
interface IGenericTableRowJson extends ITableRowBaseJson {
    kind: "generic_row";
    cells: IGenericTableCellJson[];
}
interface IGenericTableCellBaseJson {
    kind: GenericTableCellKind;
    cell_id: string;
    value: string | ITableLinkJson;
    align: TableCellAlignment;
    wrap?: TableCellTextWrapping;
    icon?: ITableIconJson;
    width?: TableCellWidth;
    style?: TableCellStyle;
}
export interface IGenericTableCellJson extends IGenericTableCellBaseJson {
    sub_cell?: IGenericTableCellBaseJson;
}
export interface IGenericTableHeadingJson {
    text: string;
    align: TableCellAlignment;
    cell_id: string;
    width?: TableCellWidth;
    wrap?: TableCellTextWrapping;
}
interface ITableLinkJson {
    kind: "table_link";
    text: string;
    url: string;
    link_type?: MessagePartHyperLinkType;
    link_style?: MessagePartHyperLinkStyle;
    show_icon?: boolean;
    data_role?: string;
}
interface ITableIconJson {
    kind: TableIconKind;
    position: TableIconPosition;
}
export type MessagePartTypesJson = IMessagePartTextJson | IMessagePartExplanationJson | IMessagePartSummaryJson | IMessagePartHyperlinkJson | IMessagePartDetailSeparatorJson | IMessagePartIntacctCloseHeadingJson | IMessagePartPromptJson | IMessagePartTableJson | IMessagePartTitleJson | IMessagePartChartJson | IMessagePartSubmitSelectJson | IMessagePartSubmitTextJson | IMessagePartSubmitJson | IMessagePartCustom1Json | IMessagePartCustom2Json | IMessagePartPollInsightsJson | IMessagePartProxiedQueryDefinitionJson;
declare class GenericTableCellBase implements IGenericTableCellBase {
    kind: GenericTableCellKind;
    cell_id: UUIDType;
    value: string | Date | ITableLink;
    align: TableCellAlignment;
    wrap: TableCellTextWrapping;
    icon: TableIcon;
    style: TableCellStyle;
    constructor(json: IGenericTableCellBaseJson, dataRoleCounter: DataRoleCounter);
}
export declare class GenericTableCell extends GenericTableCellBase implements IGenericTableCell {
    sub_cell?: IGenericTableCellBase | undefined;
    width: TableCellWidth;
    constructor(json: IGenericTableCellJson, dataRoleCounter: DataRoleCounter, numColumns: number);
    static getCellWidth: (jsonWidth: string | undefined, defaultWidth: TableCellWidth) => TableCellWidth;
}
declare class TableIcon implements ITableIcon {
    kind: TableIconKind;
    position: TableIconPosition;
    constructor(json: ITableIconJson);
}
export declare const createMessageParts: (json: MessagePartTypesJson[] | null | undefined) => IMessagePartBase[];
export {};
