import { MessagePartDisplayFn } from "../../features/chat/messageParts/messagePartDisplayHandlers";
import { ChatRequest, ChatResponse, ProxiedQueryResultRequest } from "../../types/ChatRequest";
import { InsightPatch, InsightRequestTypes } from "../../types/Insights";
import { MessagePatch } from "../../types/MessagePatch";
import { Session, SessionIdType, SessionPatch } from "../../types/Session";
import { InsightSessionMessage, SessionMessage } from "../../types/SessionMessage";
import { StarterSessionMessage } from "../../types/StarterSessionMessage";
import { SuggestionGroup } from "../../types/Suggestion";
import { BackendSettings } from "../BackendContext";
import { RequestReason } from "../../types/RequestReason.ts";
import { ChatContext } from "../../types/ChatContext.ts";
import { AutocompleteSuggestion } from "../../types/AutocompleteSuggestion.ts";
export type CustomMessagePartHandlers = Record<string, MessagePartDisplayFn>;
export interface BackendInterface {
    chat: (request: ChatRequest | ProxiedQueryResultRequest) => Promise<ChatResponse>;
    getMessages: (sessionId: SessionIdType, lastSeen: Date | null, limit: number, reason?: RequestReason) => Promise<SessionMessage[]>;
    patchMessage: (messageId: string, messagePatch: MessagePatch) => Promise<void>;
    getSessions: (reason: RequestReason) => Promise<Session[]>;
    patchSession: (sessionId: string, sessionPatch: SessionPatch) => Promise<void>;
    deleteSession: (sessionId: string) => Promise<void>;
    getInsights: (request: InsightRequestTypes, reason?: RequestReason) => Promise<InsightSessionMessage[]>;
    getInsightsFeed: (lastSeen: Date | null, limit: number, reason?: RequestReason) => Promise<{
        insights: InsightSessionMessage[];
        unreadCount: number;
    }>;
    patchInsights: (insightId: string, insightPatch: InsightPatch) => Promise<void>;
    getConversationStarter: (reason: RequestReason) => Promise<StarterSessionMessage>;
    getSuggestedPrompts: (reason: RequestReason) => Promise<SuggestionGroup>;
    postSuggestedPrompts: (context: ChatContext, reason: RequestReason) => Promise<SuggestionGroup>;
    deleteUser: (userId: string) => Promise<void>;
    name: string;
    messagePartHandlers: CustomMessagePartHandlers;
    setBackendSettings: (settings: BackendSettings) => void;
    hasValidChatContext: () => boolean;
    postAutocompleteSuggestions: (reason: RequestReason, sessionId: string, message: string) => Promise<AutocompleteSuggestion[]>;
}
