import { WorkOrderProductLine } from '@sage/x3-manufacturing-api';
import { extractEdges } from '@sage/xtrem-client';
import * as ui from '@sage/xtrem-ui';

/** Get the BOM code required for operation tracking/creation of lines
 * @param workOrderNumber
 * @returns
 */

type WorkOrderProductLineCodes = {
    bomCode: {
        code: number;
    };
    product: {
        code: string;
    };
};

export async function getBomCode(workOrderNumber: string, page: ui.Page): Promise<WorkOrderProductLineCodes> {
    try {
        const result = extractEdges<WorkOrderProductLine>(
            await page.$.graph
                .node('@sage/x3-manufacturing/WorkOrderProductLine')
                .query(
                    ui.queryUtils.edgesSelector(
                        {
                            bomCode: {
                                code: true,
                            },
                            product: {
                                code: true,
                            },
                        },
                        {
                            filter: {
                                workOrder: workOrderNumber,
                            },
                        },
                    ),
                )

                .execute(),
        );
        return result[0];
    } catch (err) {
        page.$.dialog.message(
            'error',
            ui.localize(
                '@sage/x3-manufacturing/pages__mobile_tracking___loading_BOM_code_error',
                'Error loading BOM code.',
            ),
            String(err),
        );
        return {
            bomCode: { code: 0 },
            product: { code: '' },
        };
    }
}
