import { TransactionProductionReporting } from '@sage/x3-manufacturing-api';
import { extractEdges } from '@sage/xtrem-client';
import * as ui from '@sage/xtrem-ui';

export type TransactionList = {
    transaction: string;
    employeeEntry: string;
    unplannedOperations: boolean;
};

export async function getEntryTransaction(page: ui.Page, trackingType: number): Promise<TransactionList[]> {
    try {
        const transactions = extractEdges<TransactionProductionReporting>(
            await page.$.graph
                .node('@sage/x3-manufacturing/TransactionProductionReporting')
                .query(
                    ui.queryUtils.edgesSelector(
                        {
                            transaction: true,
                            employeeEntry: true,
                            unplannedOperations: true,
                        },
                        {
                            filter: {
                                type: trackingType,
                                isActive: true,
                            },
                        },
                    ),
                )
                .execute(),
        ) as TransactionProductionReporting[];
        return transactions.map(transaction => ({
            transaction: transaction.transaction,
            employeeEntry: transaction.employeeEntry,
            unplannedOperations: transaction.unplannedOperations,
        }));
    } catch (err) {
        page.$.dialog.message(
            'error',
            ui.localize(
                '@sage/x3-manufacturing/pages__mobile_tracking___loading_transaction_list_error',
                'Error loading transaction list.',
            ),
            String(err),
        );
        return [];
    }
}
