import { WorkOrderProductLine } from '@sage/x3-manufacturing-api';
import { extractEdges } from '@sage/xtrem-client';
import * as ui from '@sage/xtrem-ui';

/** Function gets the release unit of measure for a given work order number of a given page ( i.e. passing the 'this' keyword ) -
 *      Returns the release unit of measure */

export async function getReleaseUOM(workOrderNumber: string, page: ui.Page): Promise<string> {
    try {
        const result = extractEdges<WorkOrderProductLine>(
            await page.$.graph
                .node('@sage/x3-manufacturing/WorkOrderProductLine')
                .query(
                    ui.queryUtils.edgesSelector(
                        {
                            releaseUnit: { code: true },
                        },
                        {
                            filter: {
                                workOrder: workOrderNumber,
                            },
                        },
                    ),
                )

                .execute(),
        );
        return result[0].releaseUnit.code.toString();
    } catch (err) {
        page.$.dialog.message(
            'error',
            ui.localize(
                '@sage/x3-manufacturing/pages__mobile_tracking___loading_rel_BOM_code_error',
                'Error loading the release unit.',
            ),
            String(err),
        );
        return '';
    }
}
