/* Copyright (c) 2020-2025 The Sage Group plc or its licensors. Sage, Sage logos, and Sage product and service names mentioned herein are the trademarks of Sage Global Services Limited or its licensors. All other trademarks are the property of their respective owners. */
"use strict";Object.defineProperty(exports,"__esModule",{value:true}),exports.AccessRights=void 0;const xtrem_async_helper_1=require("@sage/xtrem-async-helper"),xtrem_config_1=require("@sage/xtrem-config"),xtrem_shared_1=require("@sage/xtrem-shared"),_=require("lodash"),concurrency_utils_1=require("../../concurrency-utils"),operation_error_1=require("../../errors/operation-error"),custom_metrics_1=require("../../metrics/prometheus/custom-metrics"),runtime_1=require("../../runtime"),loggers_1=require("../../runtime/loggers"),logger=loggers_1.loggers.authorization,loggerGraphQl=loggers_1.loggers.graphQl;class AccessRights{static runSecure(e,t,r,a){return logger.debug((()=>`runSecure -> operation: ${t}`)),custom_metrics_1.CustomMetrics.graphql.withMetrics({nodeName:r.factory.name,operationName:t,operationKind:r.isMutation?"mutation":"query"},(()=>(0,concurrency_utils_1.runResolver)(e,(async()=>{if(await(0,xtrem_shared_1.withRethrow)((async()=>{if(r.isMutation)AccessRights.checkNotReadonly();await AccessRights.checkOperationAccessRight(e,{nodeName:r.factory.name,operationName:r.operation||t,args:r.args??{},isPropertyAccess:!!r.isPropertyAccess,isMutation:!!r.isMutation,operationAction:r.operationAction})}),(a=>new operation_error_1.OperationError(e,e.application.getFactoryByName(r.factory.name),t??r.operation,a instanceof xtrem_shared_1.ErrorWithDiagnoses?a.extensions.diagnoses??[]:[{severity:4,message:a.message,path:[]}],a))),e.timeLimitAsTimestamp<=Date.now())throw new xtrem_shared_1.TimeoutError("Request Timeout");try{return await a()}catch(t){throw AccessRights.logInputData(e,r),t}}))))}static isPackageAvailable(e,t){return xtrem_config_1.ConfigManager.current.storage?.managedExternal||"all"===t[0]||t.includes(e.name)}static checkNotReadonly(){if(xtrem_config_1.ConfigManager.current.graphql.isReadonly)throw new xtrem_shared_1.AuthorizationError("Mutations are not allowed. Endpoint is readonly")}static async isOperationAvailable(e,t){const{operationName:r,nodeName:a}=t,s=e.isServiceOptionEnabled.bind(e),i=e.application.getFactoryByName(a);if(i.serviceOptions&&!await(0,xtrem_async_helper_1.asyncArray)(i.serviceOptions).every(s))return false;if(t.isMutation){const e=i.mutations.find((e=>e.name===r));return(0,xtrem_async_helper_1.asyncArray)(e?.serviceOptions?.()||[]).every(s)}const o=i.queries.find((e=>e.name===r));return(0,xtrem_async_helper_1.asyncArray)(o?.serviceOptions?.()||[]).every(s)}static getAuthorizedByAccess(e,t,r,a,s,i){if(r?.authorizedBy){const o=t.nodeConstructor[r.authorizedBy];if("function"!=typeof o)throw t.logicError(`Authorization query ${a} is not a function`);const n=r.parameters.map((e=>s?s[e.name]:void 0));return o.apply(t.nodeConstructor,[e,...n,{action:i,trackingId:s?.trackingId}])}if(t.authorizedBy)return t.authorizedBy(e,a,s);return}static async getUserAccessOnOperation(e,{nodeName:t,operationName:r,args:a,operationAction:s,bypassAuthorizedBy:i}){const o=e.application.getFactoryByName(t),n=runtime_1.standardOperations.some((e=>e===r)),c=n?void 0:o.getOperationByName(r),u=i?void 0:await AccessRights.getAuthorizedByAccess(e,o,c,r,a??{},s);if(u)return u;let g=await runtime_1.Context.accessRightsManager.getUserAccessFor(e,t,r);if(!g||"authorized"!==g.status){if(!n){const r="query"===c?.operationKind?c:void 0;if(r&&r.isGrantedByLookup)g=await runtime_1.Context.accessRightsManager.getUserAccessFor(e,t,"lookup")}if("read"===r&&!o.denyReadOnLookupOnlyAccess&&o.hasLookupAccess)g=await runtime_1.Context.accessRightsManager.getUserAccessFor(e,t,"lookup")}return g}static mergeUserAccess(e,t){if("unavailable"===e.status)return e;if("unavailable"===t.status)return t;if("inactive"===e.status)return e;if("inactive"===t.status)return t;if("unauthorized"===e.status)return e;if("unauthorized"===t.status)return t;const intersect=(e,t)=>{if(null==e)return t;if(null==t)return e;return _.intersection(e,t)};return{status:"authorized"===e.status&&"authorized"===t.status?"authorized":"readonly",sites:intersect(e.sites,t.sites),accessCodes:intersect(e.accessCodes,t.accessCodes)}}static async getUserAccessOnOperations(e,t){const r=await(0,xtrem_async_helper_1.asyncArray)(t).reduce((async(t,r)=>{const a=await AccessRights.getUserAccessOnOperation(e,r);return null==t?a:this.mergeUserAccess(t,a)}),null);if(null==r)return{status:"unauthorized",sites:null,accessCodes:null};return r}static async checkOperationAccessRight(e,t){if(t.isPropertyAccess)return;const{nodeName:r,operationName:a,args:s,operationAction:i}=t;if(!await AccessRights.isOperationAvailable(e,{nodeName:r,operationName:a,args:s,isMutation:!!t.isMutation,isPropertyAccess:t.isPropertyAccess}))throw await logger.infoAsync((()=>`Operation ${r}.${a}' is not enabled by the current configuration of the application`)),new xtrem_shared_1.AuthorizationError(e.localize("@sage/xtrem-core/operation-not-enabled","Operation {{nodeName}}.{{operationName}} is not enabled by the configuration of the application",{nodeName:r,operationName:a}));const o=await AccessRights.getUserAccessOnOperation(e,{nodeName:r,operationName:a,args:s,operationAction:i});if(await e.user&&(!o||"authorized"!==o.status))throw new xtrem_shared_1.AuthorizationError(e.localize("@sage/xtrem-core/user-not-allowed-operation","You cannot perform this operation {{nodeName}}.{{operation}}",{nodeName:r,operation:a}));e.setAllowedAccessCodes(o)}static logInputData(e,t){if(t.args&&e.request)loggerGraphQl.error(`input data: ${JSON.stringify(t.args,runtime_1.stringifyLogReplacer)}`)}}exports.AccessRights=AccessRights;
//# sourceMappingURL=access-rights.js.map